Error data types and utilities for handling/reporting them.
The main type in this module is OxcDiagnostic, which is used by all other oxc tools to
report problems. It implements miette’s Diagnostic trait, making it compatible with other
tooling you may be using.
use oxc_diagnostics::{OxcDiagnostic, Result};
fn my_tool() -> Result<()> {
try_something().map_err(|e| OxcDiagnostic::error(e.to_string()))?;
Ok(())
}See the miette documentation for more information on how to interact with diagnostics.
Reporting
If you are writing your own tools that may produce their own errors, you can use
DiagnosticService to format and render them to a string or a stream. It can receive
Errors over a multi-producer, single consumer
use std::{sync::Arc, thread};
use oxc_diagnostics::{DiagnosticService, Error, OxcDiagnostic};
fn my_tool() -> Result<()> {
try_something().map_err(|e| OxcDiagnostic::error(e.to_string()))?;
Ok(())
}
let mut service = DiagnosticService::default();
let mut sender = service.sender().clone();
thread::spawn(move || {
let file_path_being_processed = PathBuf::from("file.txt");
let file_being_processed = Arc::new(NamedSource::new(file_path_being_processed.clone()));
for _ in 0..10 {
if let Err(diagnostic) = my_tool() {
let report = diagnostic.with_source_code(Arc::clone(&file_being_processed));
sender.send(Some(file_path_being_processed, vec![Error::new(e)]));
}
// send None to stop the service
sender.send(None);
}
});
service.run();Modules
Structs
- Diagnostic
Service - Listens for diagnostics sent over a channel by some job, and formats/reports them to the user.
- Graphical
Report Handler - Graphical
Theme - Theme used by
GraphicalReportHandlerto render fancyDiagnosticreports. - Labeled
Span - A labeled
SourceSpan. - Named
Source - Utility struct for when you have a regular
SourceCodetype that doesn’t implementname. For exampleString. Or if you want to override thenamereturned by theSourceCode. - OxcCode
- OxcDiagnostic
- Describes an error or warning that occurred.
- OxcDiagnostic
Inner