Crate oxc_diagnostics
source ·Expand description
Diagnostics Wrapper
Exports thiserror and miette
Re-exports
Structs
- A
ReportHandlerthat displays a givenReportin a quasi-graphical way, using terminal colors, unicode drawing characters, and other such things. This is the default reporter bundled withmiette. Seeset_hook()for more details on customizing your global printer. - Theme used by
GraphicalReportHandlerto render fancyDiagnosticreports. A theme consists of two things: the set of characters to be used for drawing, and theowo_colors::Styles to be used to paint various items. You can create your own custom graphical theme using this type, or you can use one of the predefined ones using the methods below.